@@ -1101,7 +1101,7 @@ def cli(
                                                 if message.replies:
                                                     reply_count = int(message.replies.replies)
                                                 else:
-                                                    reply_count = 0
+                                                    reply_count = "N/A"
 
                                                 if message.edit_date:
                                                     edit_date = str(message.edit_date)
